@@ -1,4 +1,8 @@
+# frozen_string_literal: true
+
+# The Sys module is a namespace only.
 module Sys
+  # The Platform class provides singleton methods to tell you what OS you're on.
   class Platform
     # The CPU architecture
     ARCH = File::ALT_SEPARATOR ? Uname.architecture.to_sym : Uname.machine.to_sym
@@ -8,18 +12,18 @@ module Sys
 
     # Returns the OS type, :macosx, :linux, :mingw32, etc
     IMPL = case Uname.sysname
-      when /darwin|mac/i
-        :macosx
-      when /mingw|windows/i
-        require 'rbconfig'
-        RbConfig::CONFIG['host_os'].split('_').first[/[a-z]+/i].downcase.to_sym
-      when /linux/i
-        :linux
-      when /sunos|solaris/i
-        :solaris
-      when /bsd/i
-        :bsd
-    end
+             when /darwin|mac/i
+               :macosx
+             when /mingw|windows/i
+               require 'rbconfig'
+               RbConfig::CONFIG['host_os'].split('_').first[/[a-z]+/i].downcase.to_sym
+             when /linux/i
+               :linux
+             when /sunos|solaris/i
+               :solaris
+             when /bsd/i
+               :bsd
+           end
 
     # Returns whether or not you're on a Windows OS
     def self.windows?
@@ -28,7 +32,7 @@ module Sys
 
     # Returns whether or not you're on a Unixy (non-Windows) OS
     def self.unix?
-      Uname.sysname !~ /microsoft/i ? true : false
+      Uname.sysname =~ /microsoft/i ? false : true
     end
 
     # Returns whether or not you're on a mac, i.e. OSX
